@@ -4,7 +4,9 @@ from __future__ import absolute_import
 import sys
 import threading
 import weakref
+from importlib import import_module
 
+from sentry_sdk._compat import string_types
 from sentry_sdk._types import TYPE_CHECKING
 from sentry_sdk.consts import OP, SPANDATA
 from sentry_sdk.hub import Hub, _should_send_default_pii
@@ -32,11 +34,17 @@ try:
     from django import VERSION as DJANGO_VERSION
     from django.conf import settings as django_settings
     from django.core import signals
+    from django.conf import settings
 
     try:
         from django.urls import resolve
     except ImportError:
         from django.core.urlresolvers import resolve
+
+    try:
+        from django.urls import Resolver404
+    except ImportError:
+        from django.core.urlresolvers import Resolver404
 except ImportError:
     raise DidNotEnable("Django not installed")
 
@@ -370,6 +378,18 @@ def _set_transaction_name_and_source(scope, transaction_style, request):
             transaction_name,
             source=source,
         )
+    except Resolver404:
+        urlconf = import_module(settings.ROOT_URLCONF)
+        # This exception only gets thrown when transaction_style is `function_name`
+        # So we don't check here what style is configured
+        if hasattr(urlconf, "handler404"):
+            handler = urlconf.handler404
+            if isinstance(handler, string_types):
+                scope.transaction = handler
+            else:
+                scope.transaction = transaction_from_function(
+                    getattr(handler, "view_class", handler)
+                )
     except Exception:
         pass
 
@@ -475,7 +495,6 @@ def _got_request_exception(request=None, **kwargs):
     hub = Hub.current
     integration = hub.get_integration(DjangoIntegration)
     if integration is not None:
-
         if request is not None and integration.transaction_style == "url":
             with hub.configure_scope() as scope:
                 _attempt_resolve_again(request, scope, integration.transaction_style)
@@ -504,7 +523,7 @@ class DjangoRequestExtractor(RequestExtractor):
         ]
 
         clean_cookies = {}  # type: Dict[str, Union[str, AnnotatedValue]]
-        for (key, val) in self.request.COOKIES.items():
+        for key, val in self.request.COOKIES.items():
             if key in privacy_cookies:
                 clean_cookies[key] = SENSITIVE_DATA_SUBSTITUTE
             else:
